==> 1.1.0.tar.gz: lib/src/flutter/utilities/colors/fx_colors.dart <==
import 'package:flutter/material.dart';

/// Custom color palette
abstract class FxColor {
  static const Color primary = Color(0xff4E73DF);
  static const Color secondary = Color(0xFFE4E6EF);
  static const Color success = Color(0xFF1CC88A);
  static const Color info = Color(0xFF8950FC);
  static const Color warning = Color(0xFFF6C23E);
  static const Color danger = Color(0xFFF64E60);
  static const Color light = Color(0xFFF3F6F9);
  static const Color dark = Color(0xFF222428);

  static const Color textColor = Color(0xFF565360);
  static const Color labelColor = Color(0xFF908E9B);
  static const Color disabledColor = Color(0xFFE1DFE9);
  static const Color textFieldColor = Color(0xFFEFEFF0);

  static const Color gray50 = Color(0XFFf9fafb);
  static const Color gray100 = Color(0XFFf3f4f6);
  static const Color gray200 = Color(0XFFe5e7eb);
  static const Color gray300 = Color(0XFFd1d5db);
  static const Color gray400 = Color(0XFF9ca3af);
  static const Color gray500 = Color(0XFF6b7280);
  static const Color gray600 = Color(0XFF4b5563);
  static const Color gray700 = Color(0XFF374151);
  static const Color gray800 = Color(0XFF1f2937);
  static const Color gray900 = Color(0XFF111827);

  static const Color neutral50 = Color(0XFFfafafa);
  static const Color neutral100 = Color(0XFFf5f5f5);
  static const Color neutral200 = Color(0XFFe5e5e5);
  static const Color neutral300 = Color(0XFFd4d4d4);
  static const Color neutral400 = Color(0XFFa3a3a3);
  static const Color neutral500 = Color(0XFF737373);
  static const Color neutral600 = Color(0XFF525252);
  static const Color neutral700 = Color(0XFF404040);
  static const Color neutral800 = Color(0XFF262626);
  static const Color neutral900 = Color(0XFF171717);

  static const Color red50 = Color(0XFFfef2f2);
  static const Color red100 = Color(0XFFfee2e2);
  static const Color red200 = Color(0XFFfecaca);
  static const Color red300 = Color(0XFFfca5a5);
  static const Color red400 = Color(0XFFf87171);
  static const Color red500 = Color(0XFFef4444);
  static const Color red600 = Color(0XFFdc2626);
  static const Color red700 = Color(0XFFb91c1c);
  static const Color red800 = Color(0XFF991b1b);
  static const Color red900 = Color(0XFF7f1d1d);

  static const Color green50 = Color(0XFFf0fdf4);
  static const Color green100 = Color(0XFFdcfce7);
  static const Color green200 = Color(0XFFbbf7d0);
  static const Color green300 = Color(0XFF86efac);
  static const Color green400 = Color(0XFF4ade80);
  static const Color green500 = Color(0XFF22c55e);
  static const Color green600 = Color(0XFF16a34a);
  static const Color green700 = Color(0XFF15803d);
  static const Color green800 = Color(0XFF166534);
  static const Color green900 = Color(0XFF14532d);

  static const Color blue50 = Color(0XFFeff6ff);
  static const Color blue100 = Color(0XFFdbeafe);
  static const Color blue200 = Color(0XFFbfdbfe);
  static const Color blue300 = Color(0XFF93c5fd);
  static const Color blue400 = Color(0XFF60a5fa);
  static const Color blue500 = Color(0XFF3b82f6);
  static const Color blue600 = Color(0XFF2563eb);
  static const Color blue700 = Color(0XFF1d4ed8);
  static const Color blue800 = Color(0XFF1e40af);
  static const Color blue900 = Color(0XFF1e3a8a);

  static const Color violet50 = Color(0XFFf5f3ff);
  static const Color violet100 = Color(0XFFede9fe);
  static const Color violet200 = Color(0XFFddd6fe);
  static const Color violet300 = Color(0XFFc4b5fd);
  static const Color violet400 = Color(0XFFa78bfa);
  static const Color violet500 = Color(0XFF8b5cf6);
  static const Color violet600 = Color(0XFF7c3aed);
  static const Color violet700 = Color(0XFF6d28d9);
  static const Color violet800 = Color(0XFF5b21b6);
  static const Color violet900 = Color(0XFF4c1d95);
}

==> 1.3.0.tar.gz: lib/src/flutter/utilities/colors/fx_colors.dart <==
import 'package:flutter/material.dart';

/// Custom color palette
abstract class FxColor {
  static const Color primary = Color(0xff4E73DF);
  static const Color secondary = Color(0xFFE4E6EF);
  static const Color success = Color(0xFF1CC88A);
  static const Color info = Color(0xFF8950FC);
  static const Color warning = Color(0xFFF6C23E);
  static const Color danger = Color(0xFFF64E60);
  static const Color light = Color(0xFFF3F6F9);
  static const Color dark = Color(0xFF222428);

  static const Color kcText = Color(0xFF565360);
  static const Color kcLabel = Color(0xFF908E9B);
  static const Color kcDisabled = Color(0xFFE1DFE9);
  static const Color kcTextField = Color(0xFFEFEFF0);

  // Status Colors
  static const Color kcWarningStatus = Color(0xFFF9AE3F);
  static const Color kcDangerStatus = Color(0xFFDE5050);
  static const Color kcSuccessStatus = Color(0xFF37BC64);

  // Light Status Colors
  static const Color kcWarningLightStatus = Color(0xFFFFF8DE);
  static const Color kcDangerLightStatus = Color(0xFFFFF3F3);
  static const Color kcSuccessLightStatus = Color(0xFFE2F8E9);

  static const Color gray50 = Color(0XFFf9fafb);
  static const Color gray100 = Color(0XFFf3f4f6);
  static const Color gray200 = Color(0XFFe5e7eb);
  static const Color gray300 = Color(0XFFd1d5db);
  static const Color gray400 = Color(0XFF9ca3af);
  static const Color gray500 = Color(0XFF6b7280);
  static const Color gray600 = Color(0XFF4b5563);
  static const Color gray700 = Color(0XFF374151);
  static const Color gray800 = Color(0XFF1f2937);
  static const Color gray900 = Color(0XFF111827);

  static const Color neutral50 = Color(0XFFfafafa);
  static const Color neutral100 = Color(0XFFf5f5f5);
  static const Color neutral200 = Color(0XFFe5e5e5);
  static const Color neutral300 = Color(0XFFd4d4d4);
  static const Color neutral400 = Color(0XFFa3a3a3);
  static const Color neutral500 = Color(0XFF737373);
  static const Color neutral600 = Color(0XFF525252);
  static const Color neutral700 = Color(0XFF404040);
  static const Color neutral800 = Color(0XFF262626);
  static const Color neutral900 = Color(0XFF171717);

  static const Color red50 = Color(0XFFfef2f2);
  static const Color red100 = Color(0XFFfee2e2);
  static const Color red200 = Color(0XFFfecaca);
  static const Color red300 = Color(0XFFfca5a5);
  static const Color red400 = Color(0XFFf87171);
  static const Color red500 = Color(0XFFef4444);
  static const Color red600 = Color(0XFFdc2626);
  static const Color red700 = Color(0XFFb91c1c);
  static const Color red800 = Color(0XFF991b1b);
  static const Color red900 = Color(0XFF7f1d1d);

  static const Color green50 = Color(0XFFf0fdf4);
  static const Color green100 = Color(0XFFdcfce7);
  static const Color green200 = Color(0XFFbbf7d0);
  static const Color green300 = Color(0XFF86efac);
  static const Color green400 = Color(0XFF4ade80);
  static const Color green500 = Color(0XFF22c55e);
  static const Color green600 = Color(0XFF16a34a);
  static const Color green700 = Color(0XFF15803d);
  static const Color green800 = Color(0XFF166534);
  static const Color green900 = Color(0XFF14532d);

  static const Color blue50 = Color(0XFFeff6ff);
  static const Color blue100 = Color(0XFFdbeafe);
  static const Color blue200 = Color(0XFFbfdbfe);
  static const Color blue300 = Color(0XFF93c5fd);
  static const Color blue400 = Color(0XFF60a5fa);
  static const Color blue500 = Color(0XFF3b82f6);
  static const Color blue600 = Color(0XFF2563eb);
  static const Color blue700 = Color(0XFF1d4ed8);
  static const Color blue800 = Color(0XFF1e40af);
  static const Color blue900 = Color(0XFF1e3a8a);

  static const Color violet50 = Color(0XFFf5f3ff);
  static const Color violet100 = Color(0XFFede9fe);
  static const Color violet200 = Color(0XFFddd6fe);
  static const Color violet300 = Color(0XFFc4b5fd);
  static const Color violet400 = Color(0XFFa78bfa);
  static const Color violet500 = Color(0XFF8b5cf6);
  static const Color violet600 = Color(0XFF7c3aed);
  static const Color violet700 = Color(0XFF6d28d9);
  static const Color violet800 = Color(0XFF5b21b6);
  static const Color violet900 = Color(0XFF4c1d95);
}
